@@ -2,12 +2,19 @@ package Math::Transform::List;
 use v5.16.0;
 use warnings FATAL => qw(all);
 use strict;
-our $VERSION = 20170822.1;                                                        # Monday 26 Jan 2015
+our $VERSION = "20170823.1";                                                        # Monday 26 Jan 2015
 
 my $debug = 0;
+my $debugLimit = 0;
 sub setDebug($)
  {my ($d) = @_;
-  $debug = $d;
+  $debug  = 0;
+  $debugLimit = $d;
+ }
+sub checkDebug($)
+ {my ($name) = @_;
+  ++$debug;
+  if ($debugLimit and $debug > $debugLimit) {die "Debug $name=$debug"}
  }
 
 =head1 Name
@@ -53,7 +60,7 @@ sub transform(&$@)
      }
    }
   my $N = scalar(@$L); my $N1 = $N - 1;
-die "debug1" if $debug == 1;
+checkDebug(1);
 
 # Transformations - check
 
@@ -62,41 +69,58 @@ die "debug1" if $debug == 1;
     my $p = grep {ref($_)} @p;
     $p == 0 or $p == @p or die "Transform, transformation(@p) must be all references to cycles or one cycle";
    }
-die "debug2" if $debug == 2;
-
+checkDebug(2);
 # Transformations - load
 
   my $T;
   for my $trans(0..$#trans)
    {ref($trans[$trans]) or die "transform(".(3+$trans).") ".($trans[$trans])." not a reference";
+checkDebug(3);
     my @P = @{$trans[$trans]};
+checkDebug(4);
     for my $P(0..$#P)
      {my $p = $P[$P];
+checkDebug(5);
       if (ref($p))
        {my @Q = @$p;
+checkDebug(6);
         for my $Q(0..$#Q)
          {my $q = $Q[$Q];
+checkDebug(7);
          ("$q" =~ /\A\d+\Z/ and $q > 0 and $q <= $N) or die "transform(".($trans+3)."->$P->$Q): $q not a number between 1 and $N";
+checkDebug(8);
           if ($Q)
            {my $q1 = $Q[$Q-1];
+checkDebug(9);
             !defined($T->[$trans][$q1-1]) or die "transform(".($trans+3)."->$P->$Q): transformation from $q1 to $q already defined";
+checkDebug(10);
              $T->[$trans][$q1-1] = $q-1;
            }
          }
+checkDebug(11);
         $T->[$trans][$Q[-1]-1] = $Q[0]-1;
+checkDebug(12);
        }
       else
        {("$p" =~ /\A\d+\Z/ and $p > 0 and $p <= $N) or die "transform(".($trans+3)."->$P): $p not a number between 1 and $N";
+checkDebug(13);
         if ($P)
          {my $p1 = $P[$P-1];
+checkDebug(14);
           !defined($T->[$trans][$p1]) or die "transform(".($trans+3)."->$P): transformation from $p1 to $p already defined";
+checkDebug(15);
           $T->[$trans][$p1-1] = $p-1;
+checkDebug(16);
          }
+checkDebug(17);
        }
+checkDebug(18);
      }
+checkDebug(19);
     $T->[$trans][$P[-1]-1] = $P[0]-1;
+checkDebug(20);
    }
-die "debug3" if $debug == 3;
+checkDebug(21);
 
 
 # Set unset transforms
@@ -106,7 +130,7 @@ die "debug3" if $debug == 3;
      {$T->[$a][$b] = $b unless defined $T->[$a][$b];
      }
    }
-die "debug4" if $debug == 4;
+checkDebug(22);
 
 
 # Initialize transformer
@@ -130,7 +154,7 @@ die "debug4" if $debug == 4;
        }
      }
    }
-die "debug5" if $debug == 5;
+checkDebug(23);
 
   $n                   # Number of transformations
  }
